<?php
/**
 * @file
 * Contains \Drupal\simplyhired\SimplyHiredService which is a wrapper for a third-
 * party PHP library for accessing the Simply Hired API.
 *
 * Created by PhpStorm.
 * User: ronald
 * Date: 11/6/15
 * Time: 22:23
 */

namespace Drupal\simplyhired;

use \SimplyHiredAPI;


class SimplyHiredService {

  /**
   * @var SimplyHiredAPI $connector Library class that will execute all API calls.
   */
  protected $connector;

  /**
   * @var array $results SimplyHiredJobs returned by the search query.
   */
  protected $results;

  /**
   * SimplyHiredService constructor.
   * @param string $source API endpoint to use
   * @param string $mode Whether to use XML or JSON
   */
  public function __construct() {
    $library = libraries_load('simplyhired');

    if ( is_null($this->connector) ) {
      if ( empty($library['loaded']) ) {
        trigger_error('Simply Hired API library could not be loaded.', E_USER_ERROR);
        exit;
      }
      $config = \Drupal::config('simplyhired.settings');
      $this->connector = new SimplyHiredAPI($config->get('pshid'), $config->get('auth'));
    }
    $this->results = array();
  }

  /**
   * Wrapper for SimplyHiredAPI::setClip() which sets the client IP address.
   * @param string $ip_address
   * @return void
   */
  public function setClip($ip_address) {
    $this->connector->setClip($ip_address);
  }

  /**
   * Wrapper for SimplyHiredAPI::setSource()
   *
   * @param string $source Two letter country code for the API endpoint to use.
   * @return void
   */
  public function setSource( $source ) {
    $this->connector->setSource( $source );
  }

  /**
   * Wrapper for SimplyHiredAPI::getSource() which returns the API endpoint being used.
   *
   * @return string
   */
  public function getSource() {
    return $this->connector->getSource();
  }

  /**
   * Wrapper for SimplyHiredAPI::search()
   *
   * @param string $query Search criteria for the jobs
   * @param bool|TRUE $frag Return full job description or just a teaser
   * @param array $options Other API options supported by SimplyHired
   * @return array
   */
  public function search( $query, $frag = TRUE, $options = array() ) {
    try {
      $this->results = $this->connector->search($query, $frag, $options);
    } catch (Exception $e) {
      trigger_error('SimplyhiredAPI error: ' . $e->getMessage(), E_USER_ERROR);
      exit;
    }

    return $this->results;
  }

  public static function getEndpointOptions($show_country_name=TRUE) {
    $endpoints = array(
      'ar' => ($show_country_name ? t('Argentina') : 'api.simplyhired.com.ar'),
      'au' => ($show_country_name ? t('Australia') : 'api.simplyhired.com.au'),
      'at' => ($show_country_name ? t('Austria') : 'api.simplyhired.com.at'),
      'be' => ($show_country_name ? t('Belgium') : 'api.simplyhired.com.be'),
      'br' => ($show_country_name ? t('Brazil') : 'api.simplyhired.com.br'),
      'ca' => ($show_country_name ? t('Canada') : 'api.simplyhired.ca'),
      'cn' => ($show_country_name ? t('China') : 'api.simplyhired.cn'),
      'fr' => ($show_country_name ? t('France') : 'api.simplyhired.fr'),
      'de' => ($show_country_name ? t('Germany') : 'api.simplyhired.de'),
      'in' => ($show_country_name ? t('India') : 'api.simplyhired.co.in'),
      'ie' => ($show_country_name ? t('Ireland') : 'api.simplyhired.ie'),
      'it' => ($show_country_name ? t('Italy') : 'api.simplyhired.it'),
      'jp' => ($show_country_name ? t('Japan') : 'api.simplyhired.jp'),
      'kr' => ($show_country_name ? t('South Korea') : 'api.simplyhired.kr'),
      'mx' => ($show_country_name ? t('Mexico') : 'api.simplyhired.mx'),
      'nl' => ($show_country_name ? t('Netherlands') : 'api.simplyhired.nl'),
      'pt' => ($show_country_name ? t('Portugal') : 'api.simplyhired.pt'),
      'ru' => ($show_country_name ? t('Russia') : 'api.simplyhired.ru'),
      'za' => ($show_country_name ? t('South Africa') : 'api.za.simplyhired.com'),
      'es' => ($show_country_name ? t('Spain') : 'api.simplyhired.es'),
      'se' => ($show_country_name ? t('Sweden') : 'api.simplyhired.se'),
      'ch' => ($show_country_name ? t('Switzerland') : 'api.simplyhired.ch'),
      'gb' => ($show_country_name ? t('United Kingdom') : 'api.simplyhired.co.uk'),
      'us' => ($show_country_name ? t('United States') : 'api.simplyhired.com'),
    );

    ksort($endpoints);

    return $endpoints;
  }

  public static function getSpecialFiltersOptions() {
    $filters = array(
      'agefriendly' => t('Age 50+ Friendly'),
      'diversity50' => t('Diversity Friendly'),
      'dogfriendly' => t('Dog Friendly'),
      'fortune500companies' => t('Fortune 500'),
      'glbt' => t('GLBT Friendly'),
      'green' => t('Green'),
      'newgrad' => t('New Graduate'),
      'nonprofit' => t('Non-Profit'),
      'sociallyresponsible' => t('Socially Responsible'),
      'vetfriendly' => t('Veteran Friendly'),
      'workingmother100' => t('Mom Friendly'),
    );

    ksort($filters);

    return $filters;
  }

  public static function getSortByOptions() {
    return array(
      'rd' => t('Relevance descending (default)'),
      'ra' => t('Relevance ascending'),
      'dd' => t('Last seen date descending'),
      'da' => t('Last seen date ascending'),
      'td' => t('Title descending'),
      'ta' => t('Title ascending'),
      'cd' => t('Company descending'),
      'ca' => t('Company ascending'),
      'ld' => t('Location descending'),
      'la' => t('Location ascending'),
    );
  }

  public static function getDatePostedOptions() {
    return array(
      'lv' => t('Last visited'),
      '1' => t('Last 24 hours'),
      '7' => t('Last 7 days'),
      '14' => t('Last 14 days'),
      '30' => t('Last 30 days'),
    );
  }

  public static function getJobTypeOptions() {
    return array(
      'contract' => t('Contract'),
      'full-time' => t('Full time'),
      'internship' => t('Internship'),
      'part-time' => t('Part time'),
      'permanent' => t('Permanent'),
      'seasonal' => t('Seasonal'),
      'telecommute' => t('Telecommute'),
      'temporary' => t('Temporary'),
      'volunteer' => t('Volunteer'),
    );
  }

  public static function getJobSourceOptions() {
    return array(
      'primary' => t('Primary'),
      'job_board' => t('Job boards only'),
    );
  }

  public static function getEmployerTypeOptions() {
    return array(
      'employer' => t('Direct employers'),
      'recruiter' => t('Recruiter'),
    );
  }

  public static function getEducationOptions() {
    return array(
      1 => t('Some High School'),
      2 => t('High School'),
      5 => t('Some College'),
      6 => t('Associate\'s Degree'),
      7 => t('Bachelor\'s Degree'),
      8 => t('Master\'s Degree'),
      9 => t('Doctorate'),
      10 => t('Professional'),
    );
  }

}